@@ -5,9 +5,7 @@
 #  map '/otherurl'
 # this will force the controller to be mounted on: /otherurl
 
-class MainController < Ramaze::Controller
-  layout '/page'
-
+class MainController < Controller
   # the index action is called automatically when no other action is specified
   def index
     @title = "Welcome to Ramaze!"
