@@ -3,6 +3,6 @@
 # All application related things should go into `app.rb`, this file is simply
 # for options related to running the application locally.
 
-require File.expand_path('app', File.dirname(__FILE__))
+require File.expand_path('../app', __FILE__)
 
 Ramaze.start(:adapter => :webrick, :port => 7000, :file => __FILE__)
