@@ -1,4 +1,4 @@
-require __DIR__/:facebook/:facebook
+require __DIR__('facebook/facebook')
 
 module Ramaze
   module Helper::Facebook
@@ -20,4 +20,4 @@ module Ramaze
     end
     alias fb facebook
   end
-end
\ No newline at end of file
+end
