@@ -1,9 +1,9 @@
 require "ruby-prof"
 
 module Ramaze
-  module Dispatcher
+  class Dispatcher
     class ActionProfiler < Action
-      def self.process(path)
+      def self.call(path)
         if RubyProf.running?
           super
         else
