@@ -16,9 +16,9 @@ module Ramaze
     # the +item+ argument.
     #
     # @example usage
-    #   numeric_counter(0, 'comment') # => 'no comments'
-    #   numeric_counter(1, 'comment') # => 'one comment'
-    #   numeric_counter(2, 'comment') # => '2 comments'
+    #   number_counter(0, 'comment') # => 'no comments'
+    #   number_counter(1, 'comment') # => 'one comment'
+    #   number_counter(2, 'comment') # => '2 comments'
 
     def number_counter(count, item, items = nil)
       count, item = count.to_i, item.to_s
@@ -100,27 +100,27 @@ module Ramaze
       end
     end
 
-    # copied from actionpack
+    # Copied from actionpack, and revised by insane-dreamer to fix a bug (original fails on some URLs)
     AUTO_LINK_RE = %r{
-                    (                          # leading text
-                      <\w+.*?>|                # leading HTML tag, or
-                      [^=!:'"/]|               # leading punctuation, or
-                      ^                        # beginning of line
-                    )
-                    (
-                      (?:https?://)|           # protocol spec, or
-                      (?:www\.)                # www.*
-                    )
-                    (
-                      [-\w]+                   # subdomain or domain
-                      (?:\.[-\w]+)*            # remaining subdomains or domain
-                      (?::\d+)?                # port
-                      (?:/(?:(?:[~\w\+@%-]|(?:[,.;:][^\s$])))?)* # path
-                      (?:\?[\w\+@%&=.;-]+)?     # query string
-                      (?:\#[\w\-]*)?           # trailing anchor
-                    )
-                    ([[:punct:]]|\s|<|$)       # trailing text
-                   }x unless defined? AUTO_LINK_RE
+      (                          # leading text
+        <\w+.*?>|                # leading HTML tag, or
+        [^=!:'"/]|               # leading punctuation, or
+        ^                        # beginning of line
+      )
+      (
+        (?:https?://)|           # protocol spec, or
+        (?:www\.)                # www.*
+      )
+      (
+        [-\w]+                   # subdomain or domain
+        (?:\.[-\w]+)*            # remaining subdomains or domain
+        (?::\d+)?                # port
+        (?:/(?:[~\w\+@%=\(\)-]|(?:[,.;:'][^\s<$]))*)* # path
+        (?:\?[\w\+@%&=.;:-]+)?   # query string
+        (?:\#[\w\-]*)?           # trailing anchor
+      )
+      ([[:punct:]]|<|$|)         # trailing text
+    }x unless defined? AUTO_LINK_RE
 
     # Turns all urls into clickable links.  If a block is given, each url
     # is yielded and the result is used as the link text.
@@ -150,8 +150,11 @@ module Ramaze
 
     # Maybe port to ruby < 1.8.7 ?
     def obfuscate_email(email, text = nil)
-      obfuscated = email.to_s.each_byte.map{|c| "&#%03d" % c}.join
-      %(<a href="mailto:#{obfuscated}">#{text || obfuscated}</a>)
+      obfuscated = []
+      email.to_s.each_byte{|c| obfuscated << "&#%03d" % c }
+      joined = obfuscated.join
+
+      %(<a href="mailto:#{joined}">#{text || joined}</a>)
     end
 
     # Returns Hash with tags as keys and their weight as value.
