@@ -2,23 +2,10 @@
 # All files in this distribution are subject to the terms of the Ruby license.
 
 require 'ramaze/log/logging'
-
-module Ramaze
-  Log = Innate::Log
-
-  module Logger
-    autoload :Analogger, 'ramaze/log/analogger'
-  end
-end
-
-__END__
-
-require 'ramaze/log/logging'
-require 'ramaze/log/hub'
 require 'ramaze/log/informer'
 
 begin
-  require 'win32console' if RUBY_PLATFORM =~ /win32/i
+  require 'win32console' if RUBY_PLATFORM =~ /win32/i && RUBY_VERSION < '1.9'
 rescue LoadError => ex
   puts ex
   puts "For nice colors on windows, please `gem install win32console`"
@@ -26,14 +13,14 @@ rescue LoadError => ex
 end
 
 module Ramaze
-  autoload :Analogger, "ramaze/log/analogger"
-  autoload :Knotify,   "ramaze/log/knotify"
-  autoload :Syslog,    "ramaze/log/syslog"
-  autoload :Growl,     "ramaze/log/growl"
-  autoload :Xosd,      "ramaze/log/xosd"
-  autoload :Logger,    "ramaze/log/logger"
+  Log = Innate::Log
 
-  unless defined?(Log)
-    Log = Logger::LogHub.new(Logger::Informer)
+  module Logger
+    autoload :Analogger, 'ramaze/log/analogger'
+    autoload :Knotify,   "ramaze/log/knotify"
+    autoload :Syslog,    "ramaze/log/syslog"
+    autoload :Growl,     "ramaze/log/growl"
+    autoload :Xosd,      "ramaze/log/xosd"
+    autoload :Logger,    "ramaze/log/logger"
   end
 end
