@@ -9,7 +9,7 @@ module Ramaze
 
     class Informer
       include Logging
-      include Ramaze::Traited
+      include Innate::Traited
 
       attr_accessor :out, :colorize, :log_levels
 
@@ -109,7 +109,7 @@ module Ramaze
         message
       end
 
-      # This uses Global.inform_timestamp or a date in the format of
+      # This uses timestamp trait or a date in the format of
       #   %Y-%m-%d %H:%M:%S
       #   # => "2007-01-19 21:09:32"
 
