@@ -9,6 +9,11 @@ require File.expand_path('../', __FILE__) unless defined?(Ramaze)
 
 require 'innate/spec/bacon'
 
+# minimal middleware, no exception handling
+Ramaze.middleware!(:spec){|m|
+  m.run(Ramaze::AppMap)
+}
+
 shared :rack_test do
   Ramaze.setup_dependencies
   extend Rack::Test::Methods
@@ -21,14 +26,8 @@ shared :webrat do
 
   require 'webrat'
 
-  Webrat.configure{|config| config.mode = :rack_test }
+  Webrat.configure{|config| config.mode = :rack }
 
   extend Webrat::Methods
   extend Webrat::Matchers
 end
-
-# Backwards compatibility
-shared(:mock){
-  Ramaze.deprecated('behaves_like(:mock)', 'behaves_like(:rack_test)')
-  behaves_like :rack_test
-}
