@@ -1,5 +1,8 @@
+#          Copyright (c) 2009 Michael Fellinger m.fellinger@gmail.com
+# All files in this distribution are subject to the terms of the Ruby license.
+
 shared :template_spec do
-  behaves_like :mock
+  behaves_like :rack_test
 
   def spec_template(spec_engine)
     it 'works on /' do
