@@ -1,6 +1,9 @@
 # * Encoding: UTF-8
+#
+#          Copyright (c) 2009 Michael Fellinger m.fellinger@gmail.com
+# All files in this distribution are subject to the terms of the Ruby license.
 
-require 'spec/helper'
+require File.expand_path('../../../spec/helper', __FILE__)
 require 'ramaze/gestalt'
 
 describe "Gestalt" do
