@@ -1,4 +1,7 @@
-require 'lib/ramaze/spec/helper/snippets'
+#          Copyright (c) 2009 Michael Fellinger m.fellinger@gmail.com
+# All files in this distribution are subject to the terms of the Ruby license.
+
+require File.expand_path('../../../../lib/ramaze/spec/helper/snippets', __FILE__)
 
 describe "Numeric time extensions" do
   it 'should provide times in the past' do
@@ -9,4 +12,4 @@ describe "Numeric time extensions" do
   it 'should provide times in the future' do
     2.weeks.from_now.to_i.should == (Time.now + 2*7*24*60*60).to_i
   end
-end
\ No newline at end of file
+end
