@@ -1,4 +1,7 @@
-require 'lib/ramaze/spec/helper/snippets'
+#          Copyright (c) 2009 Michael Fellinger m.fellinger@gmail.com
+# All files in this distribution are subject to the terms of the Ruby license.
+
+require File.expand_path('../../../../lib/ramaze/spec/helper/snippets', __FILE__)
 
 describe '__DIR__' do
   # this is hardly exhaustive, but better than nothing
