@@ -1,4 +1,7 @@
-require 'lib/ramaze/spec/helper/snippets'
+#          Copyright (c) 2009 Michael Fellinger m.fellinger@gmail.com
+# All files in this distribution are subject to the terms of the Ruby license.
+
+require File.expand_path('../../../../lib/ramaze/spec/helper/snippets', __FILE__)
 
 describe 'String#color' do
   it 'should define methods to return ANSI strings' do
